# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from google.cloud.rapidmigrationassessment import gapic_version as package_version

__version__ = package_version.__version__


from google.cloud.rapidmigrationassessment_v1.services.rapid_migration_assessment.async_client import (
    RapidMigrationAssessmentAsyncClient,
)
from google.cloud.rapidmigrationassessment_v1.services.rapid_migration_assessment.client import (
    RapidMigrationAssessmentClient,
)
from google.cloud.rapidmigrationassessment_v1.types.api_entities import (
    Annotation,
    Collector,
    GuestOsScan,
    VSphereScan,
)
from google.cloud.rapidmigrationassessment_v1.types.rapidmigrationassessment import (
    CreateAnnotationRequest,
    CreateCollectorRequest,
    DeleteCollectorRequest,
    GetAnnotationRequest,
    GetCollectorRequest,
    ListCollectorsRequest,
    ListCollectorsResponse,
    OperationMetadata,
    PauseCollectorRequest,
    RegisterCollectorRequest,
    ResumeCollectorRequest,
    UpdateCollectorRequest,
)

__all__ = (
    "RapidMigrationAssessmentClient",
    "RapidMigrationAssessmentAsyncClient",
    "Annotation",
    "Collector",
    "GuestOsScan",
    "VSphereScan",
    "CreateAnnotationRequest",
    "CreateCollectorRequest",
    "DeleteCollectorRequest",
    "GetAnnotationRequest",
    "GetCollectorRequest",
    "ListCollectorsRequest",
    "ListCollectorsResponse",
    "OperationMetadata",
    "PauseCollectorRequest",
    "RegisterCollectorRequest",
    "ResumeCollectorRequest",
    "UpdateCollectorRequest",
)



# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.protobuf import field_mask_pb2  # type: ignore
from google.protobuf import timestamp_pb2  # type: ignore
import proto  # type: ignore

from google.cloud.rapidmigrationassessment_v1.types import api_entities

__protobuf__ = proto.module(
    package="google.cloud.rapidmigrationassessment.v1",
    manifest={
        "CreateAnnotationRequest",
        "GetAnnotationRequest",
        "CreateCollectorRequest",
        "ListCollectorsRequest",
        "ListCollectorsResponse",
        "GetCollectorRequest",
        "DeleteCollectorRequest",
        "UpdateCollectorRequest",
        "ResumeCollectorRequest",
        "RegisterCollectorRequest",
        "PauseCollectorRequest",
        "OperationMetadata",
    },
)


class CreateAnnotationRequest(proto.Message):
    r"""Message for creating an AnnotationS.

    Attributes:
        parent (str):
            Required. Name of the parent
            (project+location).
        annotation (google.cloud.rapidmigrationassessment_v1.types.Annotation):
            Required. The resource being created.
        request_id (str):
            Optional. An optional request ID to identify
            requests.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    annotation: api_entities.Annotation = proto.Field(
        proto.MESSAGE,
        number=2,
        message=api_entities.Annotation,
    )
    request_id: str = proto.Field(
        proto.STRING,
        number=4,
    )


class GetAnnotationRequest(proto.Message):
    r"""Message for getting a specific Annotation

    Attributes:
        name (str):
            Required. Name of the resource.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class CreateCollectorRequest(proto.Message):
    r"""Message for creating a Collector.

    Attributes:
        parent (str):
            Required. Name of the parent
            (project+location).
        collector_id (str):
            Required. Id of the requesting object.
        collector (google.cloud.rapidmigrationassessment_v1.types.Collector):
            Required. The resource being created.
        request_id (str):
            Optional. An optional request ID to identify
            requests.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    collector_id: str = proto.Field(
        proto.STRING,
        number=2,
    )
    collector: api_entities.Collector = proto.Field(
        proto.MESSAGE,
        number=3,
        message=api_entities.Collector,
    )
    request_id: str = proto.Field(
        proto.STRING,
        number=4,
    )


class ListCollectorsRequest(proto.Message):
    r"""Message for requesting list of Collectors.

    Attributes:
        parent (str):
            Required. Parent value for
            ListCollectorsRequest.
        page_size (int):
            Requested page size. Server may return fewer
            items than requested. If unspecified, server
            will pick an appropriate default.
        page_token (str):
            A token identifying a page of results the
            server should return.
        filter (str):
            Filtering results.
        order_by (str):
            Hint for how to order the results.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=2,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=3,
    )
    filter: str = proto.Field(
        proto.STRING,
        number=4,
    )
    order_by: str = proto.Field(
        proto.STRING,
        number=5,
    )


class ListCollectorsResponse(proto.Message):
    r"""Message for response to listing Collectors.

    Attributes:
        collectors (MutableSequence[google.cloud.rapidmigrationassessment_v1.types.Collector]):
            The list of Collectors.
        next_page_token (str):
            A token identifying a page of results the
            server should return.
        unreachable (MutableSequence[str]):
            Locations that could not be reached.
    """

    @property
    def raw_page(self):
        return self

    collectors: MutableSequence[api_entities.Collector] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=api_entities.Collector,
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )
    unreachable: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=3,
    )


class GetCollectorRequest(proto.Message):
    r"""Message for getting a specific Collector.

    Attributes:
        name (str):
            Required. Name of the resource.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class DeleteCollectorRequest(proto.Message):
    r"""Message for deleting a Collector.

    Attributes:
        name (str):
            Required. Name of the resource.
        request_id (str):
            Optional. An optional request ID to identify
            requests. Specify a unique request ID so that if
            you must retry your request, the server will
            know to ignore the request if it has already
            been completed. The server will guarantee that
            for at least 60 minutes after the first request.

            For example, consider a situation where you make
            an initial request and the request times out. If
            you make the request again with the same request
            ID, the server can check if original operation
            with the same request ID was received, and if
            so, will ignore the second request. This
            prevents clients from accidentally creating
            duplicate commitments.

            The request ID must be a valid UUID with the
            exception that zero UUID is not supported
            (00000000-0000-0000-0000-000000000000).
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    request_id: str = proto.Field(
        proto.STRING,
        number=2,
    )


class UpdateCollectorRequest(proto.Message):
    r"""Message for updating a Collector.

    Attributes:
        update_mask (google.protobuf.field_mask_pb2.FieldMask):
            Required. Field mask is used to specify the fields to be
            overwritten in the Collector resource by the update. The
            fields specified in the update_mask are relative to the
            resource, not the full request. A field will be overwritten
            if it is in the mask. If the user does not provide a mask
            then all fields will be overwritten.
        collector (google.cloud.rapidmigrationassessment_v1.types.Collector):
            Required. The resource being updated.
        request_id (str):
            Optional. An optional request ID to identify
            requests. Specify a unique request ID so that if
            you must retry your request, the server will
            know to ignore the request if it has already
            been completed. The server will guarantee that
            for at least 60 minutes since the first request.

            For example, consider a situation where you make
            an initial request and the request times out. If
            you make the request again with the same request
            ID, the server can check if original operation
            with the same request ID was received, and if
            so, will ignore the second request. This
            prevents clients from accidentally creating
            duplicate commitments.

            The request ID must be a valid UUID with the
            exception that zero UUID is not supported
            (00000000-0000-0000-0000-000000000000).
    """

    update_mask: field_mask_pb2.FieldMask = proto.Field(
        proto.MESSAGE,
        number=1,
        message=field_mask_pb2.FieldMask,
    )
    collector: api_entities.Collector = proto.Field(
        proto.MESSAGE,
        number=2,
        message=api_entities.Collector,
    )
    request_id: str = proto.Field(
        proto.STRING,
        number=3,
    )


class ResumeCollectorRequest(proto.Message):
    r"""Message for resuming a Collector.

    Attributes:
        name (str):
            Required. Name of the resource.
        request_id (str):
            Optional. An optional request ID to identify
            requests. Specify a unique request ID so that if
            you must retry your request, the server will
            know to ignore the request if it has already
            been completed. The server will guarantee that
            for at least 60 minutes after the first request.

            For example, consider a situation where you make
            an initial request and the request times out. If
            you make the request again with the same request
            ID, the server can check if original operation
            with the same request ID was received, and if
            so, will ignore the second request. This
            prevents clients from accidentally creating
            duplicate commitments.

            The request ID must be a valid UUID with the
            exception that zero UUID is not supported
            (00000000-0000-0000-0000-000000000000).
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    request_id: str = proto.Field(
        proto.STRING,
        number=2,
    )


class RegisterCollectorRequest(proto.Message):
    r"""Message for registering a Collector.

    Attributes:
        name (str):
            Required. Name of the resource.
        request_id (str):
            Optional. An optional request ID to identify
            requests. Specify a unique request ID so that if
            you must retry your request, the server will
            know to ignore the request if it has already
            been completed. The server will guarantee that
            for at least 60 minutes after the first request.

            For example, consider a situation where you make
            an initial request and the request times out. If
            you make the request again with the same request
            ID, the server can check if original operation
            with the same request ID was received, and if
            so, will ignore the second request. This
            prevents clients from accidentally creating
            duplicate commitments.

            The request ID must be a valid UUID with the
            exception that zero UUID is not supported
            (00000000-0000-0000-0000-000000000000).
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    request_id: str = proto.Field(
        proto.STRING,
        number=2,
    )


class PauseCollectorRequest(proto.Message):
    r"""Message for pausing a Collector.

    Attributes:
        name (str):
            Required. Name of the resource.
        request_id (str):
            Optional. An optional request ID to identify
            requests. Specify a unique request ID so that if
            you must retry your request, the server will
            know to ignore the request if it has already
            been completed. The server will guarantee that
            for at least 60 minutes after the first request.

            For example, consider a situation where you make
            an initial request and the request times out. If
            you make the request again with the same request
            ID, the server can check if original operation
            with the same request ID was received, and if
            so, will ignore the second request. This
            prevents clients from accidentally creating
            duplicate commitments.

            The request ID must be a valid UUID with the
            exception that zero UUID is not supported
            (00000000-0000-0000-0000-000000000000).
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    request_id: str = proto.Field(
        proto.STRING,
        number=2,
    )


class OperationMetadata(proto.Message):
    r"""Represents the metadata of the long-running operation.

    Attributes:
        create_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. The time the operation was
            created.
        end_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. The time the operation finished
            running.
        target (str):
            Output only. Server-defined resource path for
            the target of the operation.
        verb (str):
            Output only. Name of the verb executed by the
            operation.
        status_message (str):
            Output only. Human-readable status of the
            operation, if any.
        requested_cancellation (bool):
            Output only. Identifies whether the user has requested
            cancellation of the operation. Operations that have
            successfully been cancelled have [Operation.error][] value
            with a [google.rpc.Status.code][google.rpc.Status.code] of
            1, corresponding to ``Code.CANCELLED``.
        api_version (str):
            Output only. API version used to start the
            operation.
    """

    create_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=1,
        message=timestamp_pb2.Timestamp,
    )
    end_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=2,
        message=timestamp_pb2.Timestamp,
    )
    target: str = proto.Field(
        proto.STRING,
        number=3,
    )
    verb: str = proto.Field(
        proto.STRING,
        number=4,
    )
    status_message: str = proto.Field(
        proto.STRING,
        number=5,
    )
    requested_cancellation: bool = proto.Field(
        proto.BOOL,
        number=6,
    )
    api_version: str = proto.Field(
        proto.STRING,
        number=7,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.protobuf import timestamp_pb2  # type: ignore
import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.cloud.rapidmigrationassessment.v1",
    manifest={
        "GuestOsScan",
        "VSphereScan",
        "Collector",
        "Annotation",
    },
)


class GuestOsScan(proto.Message):
    r"""Message describing a MC Source of type Guest OS Scan.

    Attributes:
        core_source (str):
            reference to the corresponding Guest OS Scan
            in MC Source.
    """

    core_source: str = proto.Field(
        proto.STRING,
        number=1,
    )


class VSphereScan(proto.Message):
    r"""Message describing a MC Source of type VSphere Scan.

    Attributes:
        core_source (str):
            reference to the corresponding VSphere Scan
            in MC Source.
    """

    core_source: str = proto.Field(
        proto.STRING,
        number=1,
    )


class Collector(proto.Message):
    r"""Message describing Collector object.

    Attributes:
        name (str):
            name of resource.
        create_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. Create time stamp.
        update_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. Update time stamp.
        labels (MutableMapping[str, str]):
            Labels as key value pairs.
        display_name (str):
            User specified name of the Collector.
        description (str):
            User specified description of the Collector.
        service_account (str):
            Service Account email used to ingest data to
            this Collector.
        bucket (str):
            Output only. Store cloud storage bucket name
            (which is a guid) created with this Collector.
        expected_asset_count (int):
            User specified expected asset count.
        state (google.cloud.rapidmigrationassessment_v1.types.Collector.State):
            Output only. State of the Collector.
        client_version (str):
            Output only. Client version.
        guest_os_scan (google.cloud.rapidmigrationassessment_v1.types.GuestOsScan):
            Output only. Reference to MC Source Guest Os
            Scan.
        vsphere_scan (google.cloud.rapidmigrationassessment_v1.types.VSphereScan):
            Output only. Reference to MC Source vsphere_scan.
        collection_days (int):
            How many days to collect data.
        eula_uri (str):
            Uri for EULA (End User License Agreement)
            from customer.
    """

    class State(proto.Enum):
        r"""-- Using suggestion from API Linter Analyzer for nesting enum -- --
        https://linter.aip.dev/216/nesting -- State of a Collector
        (server_side). States are used for internal purposes and named to
        keep convention of legacy product:
        https://cloud.google.com/migrate/stratozone/docs/about-stratoprobe.

        Values:
            STATE_UNSPECIFIED (0):
                Collector state is not recognized.
            STATE_INITIALIZING (1):
                Collector started to create, but hasn't been
                completed MC source creation and db object
                creation.
            STATE_READY_TO_USE (2):
                Collector has been created, MC source
                creation and db object creation completed.
            STATE_REGISTERED (3):
                Collector client has been registered with
                client.
            STATE_ACTIVE (4):
                Collector client is actively scanning.
            STATE_PAUSED (5):
                Collector is not actively scanning.
            STATE_DELETING (6):
                Collector is starting background job for
                deletion.
            STATE_DECOMMISSIONED (7):
                Collector completed all tasks for deletion.
            STATE_ERROR (8):
                Collector is in error state.
        """
        STATE_UNSPECIFIED = 0
        STATE_INITIALIZING = 1
        STATE_READY_TO_USE = 2
        STATE_REGISTERED = 3
        STATE_ACTIVE = 4
        STATE_PAUSED = 5
        STATE_DELETING = 6
        STATE_DECOMMISSIONED = 7
        STATE_ERROR = 8

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    create_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=2,
        message=timestamp_pb2.Timestamp,
    )
    update_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=3,
        message=timestamp_pb2.Timestamp,
    )
    labels: MutableMapping[str, str] = proto.MapField(
        proto.STRING,
        proto.STRING,
        number=4,
    )
    display_name: str = proto.Field(
        proto.STRING,
        number=5,
    )
    description: str = proto.Field(
        proto.STRING,
        number=6,
    )
    service_account: str = proto.Field(
        proto.STRING,
        number=7,
    )
    bucket: str = proto.Field(
        proto.STRING,
        number=8,
    )
    expected_asset_count: int = proto.Field(
        proto.INT64,
        number=9,
    )
    state: State = proto.Field(
        proto.ENUM,
        number=10,
        enum=State,
    )
    client_version: str = proto.Field(
        proto.STRING,
        number=11,
    )
    guest_os_scan: "GuestOsScan" = proto.Field(
        proto.MESSAGE,
        number=12,
        message="GuestOsScan",
    )
    vsphere_scan: "VSphereScan" = proto.Field(
        proto.MESSAGE,
        number=13,
        message="VSphereScan",
    )
    collection_days: int = proto.Field(
        proto.INT32,
        number=14,
    )
    eula_uri: str = proto.Field(
        proto.STRING,
        number=15,
    )


class Annotation(proto.Message):
    r"""Message describing an Annotation

    Attributes:
        name (str):
            name of resource.
        create_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. Create time stamp.
        update_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. Update time stamp.
        labels (MutableMapping[str, str]):
            Labels as key value pairs.
        type_ (google.cloud.rapidmigrationassessment_v1.types.Annotation.Type):
            Type of an annotation.
    """

    class Type(proto.Enum):
        r"""Types for project level setting.

        Values:
            TYPE_UNSPECIFIED (0):
                Unknown type
            TYPE_LEGACY_EXPORT_CONSENT (1):
                Indicates that this project has opted into
                StratoZone export.
            TYPE_QWIKLAB (2):
                Indicates that this project is created by
                Qwiklab.
        """
        TYPE_UNSPECIFIED = 0
        TYPE_LEGACY_EXPORT_CONSENT = 1
        TYPE_QWIKLAB = 2

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    create_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=2,
        message=timestamp_pb2.Timestamp,
    )
    update_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=3,
        message=timestamp_pb2.Timestamp,
    )
    labels: MutableMapping[str, str] = proto.MapField(
        proto.STRING,
        proto.STRING,
        number=4,
    )
    type_: Type = proto.Field(
        proto.ENUM,
        number=5,
        enum=Type,
    )


__all__ = tuple(sorted(__protobuf__.manifest))
